from django import forms
from django.contrib import admin

from .models import Category, Post


class PostFormAdmin(forms.ModelForm):
    class Meta:
        model = Post
        fields = '__all__'
        widgets = {
            'content': forms.Textarea(attrs={
                'class': 'vLargeTextField fullwidth',
                'rows': 32,
            })
        }


@admin.register(Post)
class PostAdmin(admin.ModelAdmin):
    form = PostFormAdmin
    list_display = ['title', 'slug', 'category', 'is_visible', 'weight', 'created']
    list_filter = ['is_visible', 'category']
    list_editable = ['weight']


@admin.register(Category)
class CategoryAdmin(admin.ModelAdmin):
    form = PostFormAdmin
    list_display = ['title', 'created']



from django.db import models
from django.utils.translation import ugettext_lazy as _

from .managers import CategoryManager, PostManager


class Category(models.Model):
    title = models.CharField(_('title'), max_length=255)
    created = models.DateTimeField(_('created'), auto_now_add=True)
    modified = models.DateTimeField(_('modified'), auto_now=True)
    objects = CategoryManager()

    class Meta:
        verbose_name = _('category')
        verbose_name_plural = _('categories')
        ordering = ['title']

    def __str__(self):
        return self.title


class Post(models.Model):
    category = models.ForeignKey(
        Category, verbose_name=_('category'), null=True, default=None, blank=True, on_delete=models.SET_NULL
    )
    title = models.CharField(_('title'), max_length=255)
    slug = models.SlugField(_('slug'), max_length=255, unique=True)
    preview = models.ImageField(_('preview'), blank=True)
    excerpt = models.TextField(_('excerpt'), blank=True)
    content = models.TextField(_('content'), blank=True)
    is_visible = models.BooleanField(_('visible'), default=False)
    weight = models.IntegerField(_('weight'), default=0, blank=True, null=True)
    created = models.DateTimeField(_('created'), auto_now_add=True)
    modified = models.DateTimeField(_('modified'), auto_now=True)
    objects = PostManager()

    class Meta:
        verbose_name = _('post')
        verbose_name_plural = _('posts')
        ordering = ['-weight', '-created']

    def __str__(self):
        return self.title



from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Category',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=255, verbose_name='title')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='created')),
                ('modified', models.DateTimeField(auto_now=True, verbose_name='modified')),
            ],
        ),
        migrations.CreateModel(
            name='CategoryManager',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
            ],
        ),
        migrations.CreateModel(
            name='Post',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=255, verbose_name='title')),
                ('slug', models.SlugField(max_length=255, unique=True, verbose_name='slug')),
                ('preview', models.ImageField(blank=True, upload_to='', verbose_name='preview')),
                ('excerpt', models.TextField(blank=True, verbose_name='excerpt')),
                ('content', models.TextField(blank=True, verbose_name='content')),
                ('is_visible', models.BooleanField(default=False, verbose_name='visible')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='created')),
                ('modified', models.DateTimeField(auto_now=True, verbose_name='modified')),
                ('category', models.ForeignKey(blank=True, default=None, null=True, on_delete=django.db.models.deletion.SET_NULL, to='microblog.Category', verbose_name='Category')),
            ],
            options={
                'verbose_name': 'post',
                'verbose_name_plural': 'posts',
                'ordering': ['-created', 'created'],
            },
        ),
    ]



# Generated by Django 3.0 on 2020-07-04 09:01

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('microblog', '0002_add_weight'),
    ]

    operations = [
        migrations.AlterField(
            model_name='post',
            name='weight',
            field=models.IntegerField(blank=True, default=0, null=True, verbose_name='weight'),
        ),
    ]



from django.urls import path

from .views import PostDetailView, PostListView


app_name = 'microblog'

urlpatterns = [
    path('<slug:slug>/', PostDetailView.as_view(), name='detail'),
    path('', PostListView.as_view(), name='list')
]



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['microblog', 'microblog.migrations']

package_data = \
{'': ['*'], 'microblog': ['fixtures/*']}

install_requires = \
['django>=3.0,<4.0', 'pillow>=7.0,<8.0']

setup_kwargs = {
    'name': 'django-microblog',
    'version': '0.1.2',
    'description': 'Simple blogging application for Django',
    'long_description': '# django-microblog\n\n![](https://img.shields.io/badge/Version-0.1.0-orange.svg?style=flat-square)\n![](https://img.shields.io/badge/Django-2.0+-green.svg?style=flat-square)\n![](https://img.shields.io/badge/License-MIT-blue.svg?style=flat-square)\n\ndjango-microblog minimal blogging application for Django\n\n## Getting started\n\n1. Installation\n\n```bash\npip install django-microblog\n```\n\n2. Add **microblog** into **INSTALLED_APPS** in your settings file.',
    'author': None,
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/lukasvinclav/django-microblog',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
